#include <LiquidCrystal.h>
#include <LCDKeypad.h>

byte Bell[8] = {
  B00000,
  B00100,
  B01110,
  B01110,
  B01110,
  B11111,
  B00000,
  B00100
};

// klok / wekker
int starttime;
int activetime;
int prevoustime = 0;
int hours = 00;
int mins = 00;
int secs = 0;
int AlarmHours = 00;
int AlarmMinutes = 02;
LCDKeypad lcd;

// geluid
bool PlaySound;
int noteDuration = 0;

// tijd
unsigned long startTime;
unsigned long currentTime;
unsigned long previousTime = 0;

// timer
const long timerDuration = 10;
bool DeactivatedAlarm;

// sensor
int SensorThreshold;
int pirPin = 3;  // pin voor de HC-S501 sensor
int pirValue;    // uitgelezen sensor waarde'
bool Movemend;

void setup() {
  PlaySound = true;
  DeactivatedAlarm = false;

  lcd.begin(16, 2);
  lcd.clear();

  Serial.begin(9600);
  pinMode(A0, INPUT);
  pinMode(A1, OUTPUT);
  Movemend = false;

  // hier bepaal ik de begin tijd van de arduino
  starttime = millis() / 1000;
  lcd.createChar(1, Bell);
}

void loop() {


  int A0 = analogRead(A0);
  lcd.setCursor(5, 0);
  lcd.write(byte(1));
  lcd.setCursor(11, 0);
  lcd.write(byte(1));
  lcd.setCursor(3, 1);
  lcd.print((String) "Alarm: ");

  // hier check hij voor Input
  CheckInput();

  lcd.setCursor(5, 0);
  lcd.write(byte(1));
  lcd.setCursor(11, 0);
  lcd.write(byte(1));
  lcd.setCursor(3, 1);
  lcd.print((String) "Alarm: ");

  // hier update hij de klok
  UpdateKlok();
  // hier wordt gecheckt of het alarm af moet gaan;
  CheckOfWekkerAfMagGaan();

  //checkt of de de sensor bewegiging heeft gedetect en zo ja speel het geluid af
  CheckSensor();
  lcd.clear();
}

void CheckOfWekkerAfMagGaan() {
  if (AlarmHours == hours && AlarmMinutes == mins && PlaySound == true)  // change 8 and 30 to your time for this to ring
  {
    CheckInput();
    SpeelGeluidAf();
  } else {
    noTone(2);
    delay(300);
  }
}

void SpeelGeluidAf() {
  tone(2, 1000, noteDuration * 0.9);
}

void UpdateKlok() {
  if (AlarmMinutes > 59) {
    AlarmHours++;
    AlarmMinutes = 0;
  }
  if (AlarmHours > 23) {
    AlarmHours = 0;
  }
  lcd.setCursor(9, 1);
  if (AlarmHours < 10) {
    lcd.print("0");
    lcd.print(AlarmHours);
  } else {
    lcd.print(AlarmHours);
  }

  lcd.print(":");

  if (AlarmMinutes < 10) {
    lcd.print("0");
    lcd.print(AlarmMinutes);
  } else {
    lcd.print(AlarmMinutes);
  }
  lcd.setCursor(15, 1);
  lcd.print(" ");


  activetime = (millis() / 1000) - starttime;
  if (secs < 59) {
    secs++;
  }

  if (secs > 59) {
    mins++;
    secs = 0;
  }

  if (prevoustime < (activetime - 59)) {
    mins++;
    PlaySound = true;
    prevoustime = activetime;
  }

  if (mins > 59) {
    hours++;
    mins = 0;
  }

  if (hours > 23) {
    hours = 0;
  }


  lcd.setCursor(6, 0);

  if (hours < 10) {
    lcd.print("0");
    lcd.print(hours);
  } else {
    lcd.print(hours);
  }

  lcd.print(":");

  if (mins < 10) {
    lcd.print("0");
    lcd.print(mins);
  } else {
    lcd.print(mins);
  }

  lcd.print("");
}

void CheckInput() {
  int button = lcd.button();
  switch (button) {
    case KEYPAD_UP:
      lcd.clear();
      lcd.setCursor(5, 1);
      lcd.print("Set Time");
      lcd.setCursor(6, 0);
      mins++;
      break;
    case KEYPAD_DOWN:
      lcd.clear();
      lcd.setCursor(5, 1);
      lcd.print("Set Time");
      lcd.setCursor(6, 0);
      hours++;
      break;
    case KEYPAD_LEFT:
      lcd.clear();
      lcd.setCursor(5, 1);
      lcd.print("Set Time");
      lcd.setCursor(6, 0);
      if (DeactivatedAlarm == true) {
        SensorThreshold = 0;
        DeactivatedAlarm = false;
        Movemend = false;        

        noTone(2);
      } else {
        AlarmMinutes++;
      }
      break;
    case KEYPAD_RIGHT:
      lcd.clear();
      lcd.setCursor(5, 1);
      lcd.print("Set Time");
      lcd.setCursor(6, 0);
      AlarmHours++;
      break;
    case KEYPAD_SELECT:
      if (AlarmHours == hours && AlarmMinutes == mins && PlaySound == true) {
        PlaySound = false;
        DeactivatedAlarm = true;
        previousTime = currentTime;
        noTone(2);
      }
      noTone(2);
  }
}

void CheckSensor() {
  currentTime = (millis() / 1000UL) - startTime;
  pirValue = digitalRead(pirPin);
  Serial.println(pirValue);

  //timer check of ik door de deur ben;
  if (currentTime - previousTime >= timerDuration && Movemend == false && DeactivatedAlarm == true) {
    SpeelGeluidAf();
  }

  if (pirValue == 1 && DeactivatedAlarm == true) {
    SensorThreshold = SensorThreshold + pirValue;
    if (SensorThreshold == 5) {
      Movemend = true;
    }
  }
}